Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(426)

Unified Diff: third_party/WebKit/Source/core/layout/ng/ng_layout_algorithm.h

Issue 2702403003: [layoutng] Split NGLayoutResult out of NGPhysicalFragment (Closed)
Patch Set: rebased Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/layout/ng/ng_layout_algorithm.h
diff --git a/third_party/WebKit/Source/core/layout/ng/ng_layout_algorithm.h b/third_party/WebKit/Source/core/layout/ng/ng_layout_algorithm.h
index 99b8da2adc557387ee9ea1268929303a38a2e389..bc2250cec7b25193b47906baee9edc72530f487d 100644
--- a/third_party/WebKit/Source/core/layout/ng/ng_layout_algorithm.h
+++ b/third_party/WebKit/Source/core/layout/ng/ng_layout_algorithm.h
@@ -14,7 +14,7 @@
namespace blink {
struct MinAndMaxContentSizes;
-class NGPhysicalFragment;
+class NGLayoutResult;
// Base class for all LayoutNG algorithms.
class CORE_EXPORT NGLayoutAlgorithm {
@@ -24,10 +24,10 @@ class CORE_EXPORT NGLayoutAlgorithm {
virtual ~NGLayoutAlgorithm() {}
// Actual layout function. Lays out the children and descendents within the
// constraints given by the NGConstraintSpace. Returns a fragment with the
// resulting layout information.
// TODO(layout-dev): attempt to make this function const.
- virtual RefPtr<NGPhysicalFragment> Layout() = 0;
+ virtual RefPtr<NGLayoutResult> Layout() = 0;
// Computes the min-content and max-content intrinsic sizes for the given box.
// The result will not take any min-width, max-width or width properties into
@@ -24,10 +24,10 @@ class CORE_EXPORT NGLayoutAlgorithm {
virtual ~NGLayoutAlgorithm() {}
// Actual layout function. Lays out the children and descendents within the
- // constraints given by the NGConstraintSpace. Returns a fragment with the
- // resulting layout information.
+ // constraints given by the NGConstraintSpace. Returns a layout result with
+ // the resulting layout information.
// TODO(layout-dev): attempt to make this function const.

Powered by Google App Engine
This is Rietveld 408576698